==> Do-1.76.tar.gz: Do-1.76/lib/Data/Object/String/Func.pm <==
package Data::Object::String::Func;

use 5.014;

use strict;
use warnings;

use Data::Object 'Class';

extends 'Data::Object::Func';

our $VERSION = '1.76'; # VERSION

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::String::Func

=cut

=head1 ABSTRACT

Functions for String Data

=cut

=head1 SYNOPSIS

  use Data::Object::String::Func;

=cut

=head1 DESCRIPTION

Data::Object::String::Func is an abstract base class for function classes in
the Data::Object::String::Func space.

=cut

=head1 INHERITANCE

This package inherits behaviors from:

L<Data::Object::Func>

=cut

=head1 LIBRARIES

This package uses type constraints defined by:

L<Data::Object::Library>

=cut

=head1 CREDITS

Al Newkirk, C<+296>

Anthony Brummett, C<+10>

José Joaquín Atria, C<+1>

=cut

=head1 AUTHOR

Al Newkirk, C<awncorp@cpan.org>

=head1 LICENSE

Copyright (C) 2011-2019, Al Newkirk, et al.

This is free software; you can redistribute it and/or modify it under the same
terms as the Perl 5 programming language system itself.

=head1 PROJECT

L<GitHub|https://github.com/iamalnewkirk/do>

L<Projects|https://github.com/iamalnewkirk/do/projects>

L<Milestones|https://github.com/iamalnewkirk/do/milestones>

L<Contributing|https://github.com/iamalnewkirk/do/blob/master/CONTRIBUTE.mkdn>

L<Issues|https://github.com/iamalnewkirk/do/issues>

=head1 SEE ALSO

To get the most out of this distribution, consider reading the following:

L<Do>

L<Data::Object>

L<Data::Object::Class>

L<Data::Object::ClassHas>

L<Data::Object::Role>

L<Data::Object::RoleHas>

L<Data::Object::Library>

=cut

==> Do-1.80.tar.gz: Do-1.80/lib/Data/Object/String/Func.pm <==
package Data::Object::String::Func;

use 5.014;

use strict;
use warnings;

use Data::Object 'Class';

extends 'Data::Object::Func';

our $VERSION = '1.80'; # VERSION

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::String::Func

=cut

=head1 ABSTRACT

Functions for String Data

=cut

=head1 SYNOPSIS

  use Data::Object::String::Func;

=cut

=head1 DESCRIPTION

Data::Object::String::Func is an abstract base class for function classes in
the Data::Object::String::Func space.

=cut

=head1 INHERITANCE

This package inherits behaviors from:

L<Data::Object::Func>

=cut

=head1 LIBRARIES

This package uses type constraints defined by:

L<Data::Object::Library>

=cut

=head1 CREDITS

Al Newkirk, C<+303>

Anthony Brummett, C<+10>

Adam Hopkins, C<+1>

José Joaquín Atria, C<+1>

=cut

=head1 AUTHOR

Al Newkirk, C<awncorp@cpan.org>

=head1 LICENSE

Copyright (C) 2011-2019, Al Newkirk, et al.

This is free software; you can redistribute it and/or modify it under the same
terms as the Perl 5 programming language system itself.

=head1 PROJECT

L<Wiki|https://github.com/iamalnewkirk/do/wiki>

L<Project|https://github.com/iamalnewkirk/do>

L<Initiatives|https://github.com/iamalnewkirk/do/projects>

L<Milestones|https://github.com/iamalnewkirk/do/milestones>

L<Contributing|https://github.com/iamalnewkirk/do/blob/master/CONTRIBUTE.mkdn>

L<Issues|https://github.com/iamalnewkirk/do/issues>

=head1 SEE ALSO

To get the most out of this distribution, consider reading the following:

L<Do>

L<Data::Object>

L<Data::Object::Class>

L<Data::Object::ClassHas>

L<Data::Object::Role>

L<Data::Object::RoleHas>

L<Data::Object::Library>

=cut
